==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/it-IT/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Questo utente può effettuare il login',
    'activated_disabled_help_text' => 'Non puoi modificare lo stato di attivazione del proprio account.',
    'assets_user'       => 'Bene assegnato a :name',
    'bulk_update_warn'	=> 'Stai per modificare le proprietà di: user_count users. Tieni presente che non puoi modificare i tuoi attributi utente utilizzando questo modulo e devi modificare individualmente il tuo utente.',
    'bulk_update_help'	=> 'Questo modulo consente di aggiornare più utenti contemporaneamente. Inserisci solo i campi che devi modificare. Tutti i campi lasciati vuoti rimarranno invariati.',
    'current_assets'    => 'Asset assegnato a questo utente',
    'clone'             => 'Clona Utente',
    'contact_user'      => 'Contatta :name',
    'edit'              => 'Modifica Utente',
    'filetype_info'     => 'I formati di file permessi sono png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, e rar.',
    'history_user'      => 'Storico per :name',
    'info'				=> 'Informazioni',
    'restore_user'		=> 'Clicca qui per ripristinarli.',
    'last_login'        => 'Ultimo accesso',
    'ldap_config_text'  => 'Le impostazioni di configurazione di LDAP possono essere trovate su Admin > Impostazioni. La Sede selezionata (facoltativa) verrà impostata per tutti gli utenti importati.',
    'print_assigned'    => 'Stampa tutti assegnati',
    'email_assigned'    => 'Elenco e-mail di tutti assegnati',
    'user_notified'     => 'All\'utente è stato inviato tramite e-mail un elenco degli elementi attualmente assegnati.',
    'users_notified'    => 'All\'utente è stata inviata una mail con la lista dei suoi beni.|A :count utenti è stata inviata una mail con la lista dei loro beni.',
    'users_notified_warning' => 'A :count utente è stata inviata una mail con la lista dei suoi beni, ma a :no_email utenti non è stato mandato nulla perché non hanno un indirizzo mail impostato|A :count utenti è stata inviata una mail con la lista dei loro beni, ma a :no_email utente/i non è stato mandato nulla perché non hanno un indirizzo mail impostato.',
    'auto_assign_label' => 'Includi l\'utente nella assegnazione automatica delle licenze',
    'auto_assign_help'  => 'Salta l\'utente nell\'assegnazione automatica delle licenze',
    'software_user'     => 'Software estratto a :name',
    'send_email_help'   => 'Devi fornire un indirizzo email all\'utente per inviare loro le credenziali. L\'inoltro delle credenziali via email avviene solo durante la creazione dell\'utente. La password è memorizzata in un hash unidirezionale e non può essere recuperata, una volta salvata.',
    'view_user'         => 'Visualizza Utente :name',
    'usercsv'           => 'CSV file',
    'two_factor_admin_optin_help' => 'Le impostazioni correnti consentono l\'attivazione selettiva dell\'autenticazione a due fattori.  ',
    'two_factor_enrolled' => 'Dispositivo 2FA Iscritto ',
    'two_factor_active'   => '2FA attivo ',
    'user_deactivated'  => 'L\'utente non può loggarsi',
    'user_activated'  => 'L\'utente può loggarsi',
    'activation_status_warning' => 'Non cambiare lo stato di attivazione',
    'group_memberships_helpblock' => 'Solo i superamministratori possono modificare i membri del gruppo.',
    'superadmin_permission_warning' => 'Solo i superamministratori possono concedere il permesso di superamministratore a un altro utente.',
    'admin_permission_warning' => 'Solo gli utenti con diritti di amministratore o superiore possono nominare altri utenti come amministratore.',
    'remove_group_memberships' => 'Rimuove Membri del Gruppo',
    'warning_deletion_information' => 'Stai per effettuare la restituzione di TUTTI gli articoli da :count utente/i elencati di seguito. I nomi dei super amministratori sono evidenziati in rosso.',
    'update_user_assets_status' => 'Aggiorna tutti i beni per questi utenti a questo stato',
    'checkin_user_properties' => 'Esegui la restituzione di tutte le assegnazioni associate a questi utenti',
    'remote_label'   => 'Questo è un utente remoto',
    'remote'   => 'Remoto',
    'remote_help' => 'Questo può esserti utile devi filtrare gli utenti remoti che non entrano mai o solo raramente nelle tue Sedi fisiche.',
    'not_remote_label' => 'Questo non è un utente remoto',
    'vip_label' => 'Utente VIP',
    'vip_help' => 'Puoi contrassegnare le persone importanti nella tua organizzazione, se vuoi trattarle in maniera speciale.',
    'create_user' => 'Crea utente',
    'create_user_page_explanation' => 'Queste sono le informazioni dell\'account che utilizzerai per accedere al sito per la prima volta.',
    'email_credentials' => 'Credenziali email',
    'email_credentials_text' => 'Invia le mie credenziali all\'indirizzo email qui sopra',
    'next_save_user' => 'Successivo: Salva Utente',
    'all_assigned_list_generation' => 'Generato il:',
    'email_user_creds_on_create' => 'Mandare le credenziali all\'utente?',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/it-IT/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Questo utente può effettuare il login',
    'activated_disabled_help_text' => 'Non puoi modificare lo stato di attivazione del proprio account.',
    'assets_user'       => 'Bene assegnato a :name',
    'bulk_update_warn'	=> 'Stai per modificare le proprietà di: user_count users. Tieni presente che non puoi modificare i tuoi attributi utente utilizzando questo modulo e devi modificare individualmente il tuo utente.',
    'bulk_update_help'	=> 'Questo modulo consente di aggiornare più utenti contemporaneamente. Inserisci solo i campi che devi modificare. Tutti i campi lasciati vuoti rimarranno invariati.',
    'current_assets'    => 'Asset assegnato a questo utente',
    'clone'             => 'Clona Utente',
    'contact_user'      => 'Contatta :name',
    'edit'              => 'Modifica Utente',
    'filetype_info'     => 'I formati di file permessi sono png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, e rar.',
    'history_user'      => 'Storico per :name',
    'info'				=> 'Informazioni',
    'restore_user'		=> 'Clicca qui per ripristinarli.',
    'last_login'        => 'Ultimo accesso',
    'ldap_config_text'  => 'Le impostazioni di configurazione di LDAP possono essere trovate su Admin > Impostazioni. La Sede selezionata (facoltativa) verrà impostata per tutti gli utenti importati.',
    'print_assigned'    => 'Stampa tutti assegnati',
    'email_assigned'    => 'Elenco e-mail di tutti assegnati',
    'user_notified'     => 'All\'utente è stato inviato tramite e-mail un elenco degli elementi attualmente assegnati.',
    'users_notified'    => 'All\'utente è stata inviata una mail con la lista dei suoi beni.|A :count utenti è stata inviata una mail con la lista dei loro beni.',
    'users_notified_warning' => 'A :count utente è stata inviata una mail con la lista dei suoi beni, ma a :no_email utenti non è stato mandato nulla perché non hanno un indirizzo mail impostato|A :count utenti è stata inviata una mail con la lista dei loro beni, ma a :no_email utente/i non è stato mandato nulla perché non hanno un indirizzo mail impostato.',
    'auto_assign_label' => 'Includi l\'utente nella assegnazione automatica delle licenze',
    'auto_assign_help'  => 'Salta l\'utente nell\'assegnazione automatica delle licenze',
    'software_user'     => 'Software estratto a :name',
    'view_user'         => 'Visualizza Utente :name',
    'usercsv'           => 'CSV file',
    'two_factor_admin_optin_help' => 'Le impostazioni correnti consentono l\'attivazione selettiva dell\'autenticazione a due fattori.  ',
    'two_factor_enrolled' => 'Dispositivo 2FA Iscritto ',
    'two_factor_active'   => '2FA attivo ',
    'user_deactivated'  => 'L\'utente non può loggarsi',
    'user_activated'  => 'L\'utente può loggarsi',
    'activation_status_warning' => 'Non cambiare lo stato di attivazione',
    'group_memberships_helpblock' => 'Solo i superamministratori possono modificare i membri del gruppo.',
    'superadmin_permission_warning' => 'Solo i superamministratori possono concedere il permesso di superamministratore a un altro utente.',
    'admin_permission_warning' => 'Solo gli utenti con diritti di amministratore o superiore possono nominare altri utenti come amministratore.',
    'remove_group_memberships' => 'Rimuove Membri del Gruppo',
    'warning_deletion_information' => 'Stai per effettuare la restituzione di TUTTI gli articoli da :count utente/i elencati di seguito. I nomi dei super amministratori sono evidenziati in rosso.',
    'update_user_assets_status' => 'Aggiorna tutti i beni per questi utenti a questo stato',
    'checkin_user_properties' => 'Esegui la restituzione di tutte le assegnazioni associate a questi utenti',
    'remote_label'   => 'Questo è un utente remoto',
    'remote'   => 'Remoto',
    'remote_help' => 'Questo può esserti utile devi filtrare gli utenti remoti che non entrano mai o solo raramente nelle tue Sedi fisiche.',
    'not_remote_label' => 'Questo non è un utente remoto',
    'vip_label' => 'Utente VIP',
    'vip_help' => 'Puoi contrassegnare le persone importanti nella tua organizzazione, se vuoi trattarle in maniera speciale.',
    'create_user' => 'Crea utente',
    'create_user_page_explanation' => 'Queste sono le informazioni dell\'account che utilizzerai per accedere al sito per la prima volta.',
    'email_credentials' => 'Credenziali email',
    'email_credentials_text' => 'Invia le mie credenziali all\'indirizzo email qui sopra',
    'next_save_user' => 'Successivo: Salva Utente',
    'all_assigned_list_generation' => 'Generato il:',
    'email_user_creds_on_create' => 'Mandare le credenziali all\'utente?',
    'department_manager' => 'Responsabile di Reparto',
];
